@@ -1,14 +1,12 @@
 import base64
 import io
-import subprocess
 import tarfile
 import time
 from urllib.parse import urlparse
 
-from docker.errors import ImageNotFound  # type: ignore
-from docker.models.containers import Container  # type: ignore
-from docker.models.images import Image  # type: ignore
-from docker.models.networks import Network  # type: ignore
+from docker.models.containers import Container
+from docker.models.networks import Network
+from docker.types import EndpointConfig
 
 from biolib import utils
 from biolib.biolib_api_client import BiolibApiClient, RemoteHost
@@ -16,7 +14,9 @@ from biolib.biolib_docker_client import BiolibDockerClient
 from biolib.biolib_errors import BioLibError
 from biolib.biolib_logging import logger_no_user_data
 from biolib.compute_node.cloud_utils import CloudUtils
-from biolib.typing_utils import List, Optional
+from biolib.compute_node.utils import BIOLIB_PROXY_NETWORK_NAME
+from biolib.compute_node.webserver.proxy_utils import get_biolib_nginx_proxy_image
+from biolib.typing_utils import Dict, List, Optional
 
 
 # Prepare for remote hosts with specified port
@@ -28,14 +28,12 @@ class RemoteHostProxy:
     def __init__(
         self,
         remote_host: RemoteHost,
-        public_network: Network,
         internal_network: Optional[Network],
         job_id: str,
         ports: List[int],
     ):
         self.is_app_caller_proxy = remote_host['hostname'] == 'AppCallerProxy'
         self._remote_host: RemoteHostExtended = RemoteHostExtended(hostname=remote_host['hostname'], ports=ports)
-        self._public_network: Network = public_network
         self._internal_network: Optional[Network] = internal_network
 
         if not job_id:
@@ -44,7 +42,6 @@ class RemoteHostProxy:
         self._name = f'biolib-remote-host-proxy-{job_id}-{self.hostname}'
         self._job_uuid = job_id
         self._container: Optional[Container] = None
-        self._enclave_traffic_forwarder_processes: List[subprocess.Popen] = []
         self._docker = BiolibDockerClient().get_docker_client()
 
     @property
@@ -70,23 +67,34 @@ class RemoteHostProxy:
 
         docker = BiolibDockerClient.get_docker_client()
 
+        networking_config: Optional[Dict[str, EndpointConfig]] = (
+            None
+            if not self.is_app_caller_proxy
+            else {
+                BIOLIB_PROXY_NETWORK_NAME: docker.api.create_endpoint_config(
+                    aliases=[f'biolib-app-caller-proxy-{self._job_uuid}']
+                )
+            }
+        )
+
         for index in range(3):
             logger_no_user_data.debug(f'Attempt {index} at creating RemoteHostProxy container "{self._name}"...')
             try:
                 self._container = docker.containers.create(
                     detach=True,
-                    image=self._get_biolib_remote_host_proxy_image(),
+                    image=get_biolib_nginx_proxy_image(),
                     name=self._name,
-                    network=self._public_network.name,
+                    network=BIOLIB_PROXY_NETWORK_NAME,
+                    networking_config=networking_config,
                 )
                 break
-            except Exception as error:  # pylint: disable=broad-except
+            except Exception as error:
                 logger_no_user_data.exception(f'Failed to create container "{self._name}" hit error: {error}')
 
             logger_no_user_data.debug('Sleeping before re-trying container creation...')
             time.sleep(3)
 
-        if not self._container:
+        if not self._container or not self._container.id:
             raise BioLibError(f'Exceeded re-try limit for creating container {self._name}')
 
         self._write_nginx_config_to_container(
@@ -121,26 +129,6 @@ class RemoteHostProxy:
         if self._container:
             self._container.remove(force=True)
 
-        for process in self._enclave_traffic_forwarder_processes:
-            process.terminate()
-
-    def _get_biolib_remote_host_proxy_image(self) -> Image:
-        if utils.IS_RUNNING_IN_CLOUD:
-            try:
-                logger_no_user_data.debug('Getting local Docker image for remote host proxy')
-                return self._docker.images.get('biolib-remote-host-proxy:latest')
-            except ImageNotFound:
-                logger_no_user_data.debug(
-                    'Local Docker image for remote host proxy not available. Falling back to public image...'
-                )
-
-        public_image_uri = 'public.ecr.aws/h5y4b3l1/biolib-remote-host-proxy:latest'
-        try:
-            logger_no_user_data.debug('Getting public Docker image for remote host proxy')
-            return self._docker.images.get(public_image_uri)
-        except ImageNotFound:
-            logger_no_user_data.debug('Pulling public Docker image for remote host proxy')
-            return self._docker.images.pull(public_image_uri)
 
     def _write_nginx_config_to_container(self, upstream_server_name: str, upstream_server_ports: List[int]) -> None:
         if not self._container:
