@@ -1,19 +1,24 @@
 # pylint: disable=unsubscriptable-object
 
 import json
-import os
-import time
-import tempfile
 import logging
-from flask import Flask, request, Response, jsonify
+import os
+import tempfile
+import time
+
+from docker.models.networks import Network  # type: ignore
+from flask import Flask, Response, jsonify, request
 
 from biolib import utils
 from biolib.biolib_api_client import BiolibApiClient
 from biolib.biolib_binary_format import SavedJob
-from biolib.compute_node.webserver import webserver_utils
+from biolib.biolib_docker_client import BiolibDockerClient
+from biolib.biolib_logging import TRACE, logger, logger_no_user_data
 from biolib.compute_node.cloud_utils.cloud_utils import CloudUtils
+from biolib.compute_node.utils import BIOLIB_PROXY_NETWORK_NAME
+from biolib.compute_node.webserver import webserver_utils
+from biolib.compute_node.webserver.compute_node_results_proxy import ComputeNodeResultsProxy
 from biolib.compute_node.webserver.gunicorn_flask_application import GunicornFlaskApplication
-from biolib.biolib_logging import logger, TRACE
 from biolib.compute_node.webserver.webserver_utils import get_job_compute_state_or_404
 from biolib.typing_utils import Optional
 
@@ -102,15 +107,14 @@ def status(job_id):
     response_data['is_completed'] = compute_state['is_completed']
 
     if current_status['stdout_and_stderr_packages_b64']:
-        compute_state['streamed_logs_packages_b64'] = compute_state['streamed_logs_packages_b64'] + \
-                                                      current_status['stdout_and_stderr_packages_b64']
+        compute_state['streamed_logs_packages_b64'] = (
+            compute_state['streamed_logs_packages_b64'] + current_status['stdout_and_stderr_packages_b64']
+        )
 
         compute_state['status']['stdout_and_stderr_packages_b64'] = []
 
     if current_status['status_updates']:
-        compute_state['previous_status_updates'].extend(
-            current_status['status_updates']
-        )
+        compute_state['previous_status_updates'].extend(current_status['status_updates'])
         compute_state['status']['status_updates'] = []
 
     if return_full_logs:
@@ -132,21 +136,37 @@ def send_package_to_compute_process(job_id, package_bytes):
 
 
 def start_webserver(
-        host: str,
-        port: int,
-        tls_pem_certificate_path: Optional[str] = None,
-        tls_pem_key_path: Optional[str] = None,
+    host: str,
+    port: int,
+    tls_pem_certificate_path: Optional[str] = None,
+    tls_pem_key_path: Optional[str] = None,
 ) -> None:
     def worker_exit(server, worker):  # pylint: disable=unused-argument
-        active_compute_states = list(
-            webserver_utils.JOB_ID_TO_COMPUTE_STATE_DICT.values()) + webserver_utils.UNASSIGNED_COMPUTE_PROCESSES
+        active_compute_states = (
+            list(webserver_utils.JOB_ID_TO_COMPUTE_STATE_DICT.values()) + webserver_utils.UNASSIGNED_COMPUTE_PROCESSES
+        )
         logger.debug(f'Sending terminate signal to {len(active_compute_states)} compute processes')
         if active_compute_states:
             for compute_state in active_compute_states:
                 if compute_state['worker_thread']:
                     compute_state['worker_thread'].terminate()
             time.sleep(2)
-        return
+
+        if utils.IS_RUNNING_IN_CLOUD:
+            try:
+                logger_no_user_data.debug('Stopping ComputeNodeResultsProxy')
+                ComputeNodeResultsProxy.stop_proxy()
+            except BaseException:
+                logger_no_user_data.exception('Failed to stop ComputeNodeResultsProxy')
+
+            try:
+                logger_no_user_data.debug(f'Removing Docker network {BIOLIB_PROXY_NETWORK_NAME}')
+                docker_client = BiolibDockerClient.get_docker_client()
+                biolib_proxy_network: Network = docker_client.networks.get(BIOLIB_PROXY_NETWORK_NAME)
+                biolib_proxy_network.remove()
+                logger_no_user_data.debug(f'Successfully removed Docker network {BIOLIB_PROXY_NETWORK_NAME}')
+            except BaseException:
+                logger_no_user_data.exception(f'Failed to clean up network {BIOLIB_PROXY_NETWORK_NAME}')
 
     def post_fork(server, worker):  # pylint: disable=unused-argument
         logger.info('Started compute node')
@@ -157,8 +177,33 @@ def start_webserver(
             utils.IS_DEV = config['is_dev']
             BiolibApiClient.initialize(config['base_url'])
 
-            CloudUtils.initialize()
-            webserver_utils.start_auto_shutdown_timer()
+            biolib_proxy_network: Optional[Network] = None
+            try:
+                logger_no_user_data.debug(f'Creating Docker network {BIOLIB_PROXY_NETWORK_NAME}')
+                docker_client = BiolibDockerClient.get_docker_client()
+                biolib_proxy_network = docker_client.networks.create(
+                    name=BIOLIB_PROXY_NETWORK_NAME,
+                    internal=False,
+                    driver='bridge',
+                )
+                logger_no_user_data.debug(f'Successfully created Docker network {BIOLIB_PROXY_NETWORK_NAME}')
+            except BaseException:
+                logger_no_user_data.exception(f'Failed to create Docker network {BIOLIB_PROXY_NETWORK_NAME}')
+
+            if biolib_proxy_network:
+                try:
+                    logger_no_user_data.debug('Starting ComputeNodeResultsProxy')
+                    ComputeNodeResultsProxy.start_proxy(tls_pem_certificate_path, tls_pem_key_path)
+                except BaseException:
+                    logger_no_user_data.exception('Failed to start ComputeNodeResultsProxy')
+
+                CloudUtils.initialize()
+                webserver_utils.start_auto_shutdown_timer()
+            else:
+                logger_no_user_data.error(
+                    f'Docker network {BIOLIB_PROXY_NETWORK_NAME} was not created, shutting down...'
+                )
+                CloudUtils.deregister_and_shutdown()
 
     if logger.level == TRACE:
         gunicorn_log_level_name = 'DEBUG'
