@@ -9,14 +9,15 @@ https://github.com/uktrade/stream-unzip
 import io
 import zipfile
 
-import requests
-
 from functools import partial
 from struct import Struct
 import zlib
 
 __all__ = ['RemoteIOError', 'RemoteZip']
 
+from biolib._internal.http_client import HttpClient
+
+
 class RemoteZipError(Exception):
     pass
 
@@ -152,8 +153,7 @@ class RemoteIO(io.IOBase):
 
 
 class RemoteZip(zipfile.ZipFile):
-    def __init__(self, url, initial_buffer_size=64*1024, **kwargs):
-        self.kwargs = kwargs
+    def __init__(self, url, initial_buffer_size=64*1024):
         self.url = url
 
         rio = RemoteIO(self.fetch_fun, initial_buffer_size)
@@ -191,22 +191,14 @@ class RemoteZip(zipfile.ZipFile):
             return "bytes=%s%s" % (range_min, '' if range_min < 0 else '-')
         return "bytes=%s-%s" % (range_min, range_max)
 
-    @staticmethod
-    def request(url, range_header, kwargs):
-        kwargs['headers'] = headers = dict(kwargs.get('headers', {}))
-        headers['Range'] = range_header
-        res = requests.get(url, stream=True, **kwargs)
-        res.raise_for_status()
-        if 'Content-Range' not in res.headers:
-            raise RangeNotSupported("The server doesn't support range requests")
-        return res.raw, res.headers
-
     def fetch_fun(self, data_range, stream=False):
         range_header = self.make_header(*data_range)
-        kwargs = dict(self.kwargs)
         try:
-            res, headers = self.request(self.url, range_header, kwargs)
-            return self.make_buffer(res, headers['Content-Range'], stream=stream)
+            response = HttpClient.request(url=self.url, headers={'Range': range_header})
+            if 'Content-Range' not in response.headers:
+                raise RangeNotSupported("The server doesn't support range requests")
+
+            return self.make_buffer(io.BytesIO(response.content), response.headers['Content-Range'], stream=False)
         except IOError as e:
             raise RemoteIOError(str(e))
 
